@@ -4,7 +4,7 @@ from mprop import mproperty
 from subprocess import Popen, PIPE
 import sys
 
-__version__ = "0.106.7"
+__version__ = "0.109.1"
 
 __github_repo = "jupyter-naas/drivers"
 
@@ -38,7 +38,6 @@ def load_driver(_func=None, *, extra_requires=""):
     def fn_wrapper(loader_fn):
         @mproperty
         def wrapper(mod):
-
             name = loader_fn.__name__
 
             if name not in __loaded_drivers:
@@ -434,3 +433,10 @@ def bigquery():
     from naas_drivers.tools.bigquery import BigQuery
 
     return BigQuery()
+
+
+@load_driver
+def linkedin_salesnavigator():
+    from naas_drivers.tools.linkedin_salesnavigator import LinkedIn
+
+    return LinkedIn()
