@@ -87,12 +87,6 @@ class HSCRUD:
         if hs_properties:
             params.pop("properties")
             self.params = params
-            for col in hs_properties:
-                if col not in df.columns:
-                    index = hs_properties.index(col)
-                    hs_properties.pop(index)
-            # Reorder hs_properties
-            df = df[hs_properties]
         return df
 
     def get(self, uid, hs_properties=None, idproperty=None):
@@ -430,7 +424,6 @@ class Note:
 
 
 class HubSpot(InDriver, OutDriver):
-
     base_url = os.environ.get("HUBSPOT_API_URL", "https://api.hubapi.com/crm/v3")
     api_token = None
 
